@@ -1,7 +1,9 @@
 package Sah::Schema::rinci::function_meta;
 
-our $DATE = '2019-04-15'; # DATE
-our $VERSION = '1.1.88.0'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-05-27'; # DATE
+our $DIST = 'Sah-Schemas-Rinci'; # DIST
+our $VERSION = '1.1.90.1'; # VERSION
 
 use 5.010001;
 use strict;
@@ -130,6 +132,16 @@ our $schema = [hash => {
             },
         },
     },
+
+    examples => [
+        {value=>{}, valid=>1},
+        {
+            value=>{v=>1.1, summary=>"Some function", args=>{a1=>{}, a2=>{}}},
+            valid=>1,
+        },
+        # XXX we have not implemented property & attribute checking
+    ],
+
 }, {}];
 
 $schema->[1]{_prop}{args}{_value_prop}{meta} = $schema->[1];
@@ -155,7 +167,74 @@ Sah::Schema::rinci::function_meta - Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 1.1.88.0 of Sah::Schema::rinci::function_meta (from Perl distribution Sah-Schemas-Rinci), released on 2019-04-15.
+This document describes version 1.1.90.1 of Sah::Schema::rinci::function_meta (from Perl distribution Sah-Schemas-Rinci), released on 2020-05-27.
+
+=head1 SYNOPSIS
+
+To check data against this schema (requires L<Data::Sah>):
+
+ use Data::Sah qw(gen_validator);
+ my $validator = gen_validator("rinci::function_meta*");
+ say $validator->($data) ? "valid" : "INVALID!";
+
+ # Data::Sah can also create validator that returns nice error message string
+ # and/or coerced value. Data::Sah can even create validator that targets other
+ # language, like JavaScript. All from the same schema. See its documentation
+ # for more details.
+
+To validate function parameters against this schema (requires L<Params::Sah>):
+
+ use Params::Sah qw(gen_validator);
+
+ sub myfunc {
+     my @args = @_;
+     state $validator = gen_validator("rinci::function_meta*");
+     $validator->(\@args);
+     ...
+ }
+
+To specify schema in L<Rinci> function metadata and use the metadata with
+L<Perinci::CmdLine> to create a CLI:
+
+ # in lib/MyApp.pm
+ package MyApp;
+ our %SPEC;
+ $SPEC{myfunc} = {
+     v => 1.1,
+     summary => 'Routine to do blah ...',
+     args => {
+         arg1 => {
+             summary => 'The blah blah argument',
+             schema => ['rinci::function_meta*'],
+         },
+         ...
+     },
+ };
+ sub myfunc {
+     my %args = @_;
+     ...
+ }
+ 1;
+
+ # in myapp.pl
+ package main;
+ use Perinci::CmdLine::Any;
+ Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
+
+ # in command-line
+ % ./myapp.pl --help
+ myapp - Routine to do blah ...
+ ...
+
+ % ./myapp.pl --version
+
+ % ./myapp.pl --arg1 ...
+
+Sample data:
+
+ {}  # valid
+
+ {args=>{a1=>{},a2=>{}},summary=>"Some function",v=>1.1}  # valid
 
 =head1 HOMEPAGE
 
@@ -179,7 +258,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
